pub struct ColorClass {Show 13 fields
pub aggregate: Option<Aggregate>,
pub band_position: Option<f64>,
pub bin: Option<AngleBin>,
pub condition: Option<ColorCondition>,
pub field: Option<Field>,
pub legend: RemovableValue<Legend>,
pub scale: RemovableValue<Scale>,
pub sort: RemovableValue<SortUnion>,
pub time_unit: Option<LogicalNotPredicateTimeUnit>,
pub title: RemovableValue<LegendText>,
pub mark_prop_def_gradient_string_null_type: Option<Type>,
pub datum: Option<PrimitiveValue>,
pub value: Option<ConditionalValueDefGradientStringNullExprRefValue>,
}Expand description
Color of the marks – either fill or stroke color based on the filled property of mark
definition. By default, color represents fill color for "area", "bar", "tick",
"text", "trail", "circle", and "square" / stroke color for "line" and
"point".
Default value: If undefined, the default color depends on mark
config’s color
property.
Note: 1) For fine-grained control over both fill and stroke colors of the marks, please
use the fill and stroke channels. The fill or stroke encodings have higher
precedence than color, thus may override the color encoding if conflicting encodings
are specified. 2) See the scale documentation for more information about customizing
color scheme.
Fill color of the marks. Default value: If undefined, the default color depends on
mark config’s color
property.
Note: The fill encoding has higher precedence than color, thus may override the
color encoding if conflicting encodings are specified.
Stroke color of the marks. Default value: If undefined, the default color depends on
mark config’s color
property.
Note: The stroke encoding has higher precedence than color, thus may override the
color encoding if conflicting encodings are specified.
A FieldDef with Condition
Fields
aggregate: Option<Aggregate>Aggregation function for the field (e.g., "mean", "sum", "median", "min",
"max", "count").
Default value: undefined (None)
See also: aggregate
documentation.
band_position: Option<f64>Relative position on a band of a stacked, binned, time unit, or band scale. For example,
the marks will be positioned at the beginning of the band if set to 0, and at the
middle of the band if set to 0.5.
bin: Option<AngleBin>A flag for binning a quantitative field, an object defining binning
parameters, or indicating
that the data for x or y channel are binned before they are imported into Vega-Lite
("binned").
-
If
true, default binning parameters will be applied. -
If
"binned", this indicates that the data for thex(ory) channel are already binned. You can map the bin-start field tox(ory) and the bin-end field tox2(ory2). The scale and axis will be formatted similar to binning in Vega-Lite. To adjust the axis ticks based on the bin step, you can also set the axis’stickMinStepproperty.
Default value: false
See also: bin documentation.
condition: Option<ColorCondition>One or more value definition(s) with a parameter or a test predicate.
Note: A field definition’s condition property can only contain conditional value
definitions since Vega-Lite
only allows at most one encoded field per encoding channel.
A field definition or one or more value definition(s) with a parameter predicate.
field: Option<Field>Required. A string defining the name of the field from which to pull a data value or
an object defining iterated values from the
repeat operator.
See also: field documentation.
Notes: 1) Dots (.) and brackets ([ and ]) can be used to access nested objects
(e.g., "field": "foo.bar" and "field": "foo['bar']"). If field names contain dots or
brackets but are not nested, you can use \\ to escape dots and brackets (e.g.,
"a\\.b" and "a\\[0\\]"). See more details about escaping in the field
documentation. 2) field is not
required if aggregate is count.
legend: RemovableValue<Legend>An object defining properties of the legend. If null, the legend for the encoding
channel will be removed.
Default value: If undefined, default legend properties are applied.
See also: legend documentation.
scale: RemovableValue<Scale>An object defining properties of the channel’s scale, which is the function that transforms values in the data domain (numbers, dates, strings, etc) to visual values (pixels, colors, sizes) of the encoding channels.
If null, the scale will be disabled and the data value will be directly
encoded.
Default value: If undefined, default scale properties are applied.
See also: scale documentation.
sort: RemovableValue<SortUnion>Sort order for the encoded field.
For continuous fields (quantitative or temporal), sort can be either "ascending" or
"descending".
For discrete fields, sort can be one of the following:
"ascending"or"descending"– for sorting by the values’ natural order in JavaScript.- A string indicating an encoding channel name to sort
by (e.g.,
"x"or"y") with an optional minus prefix for descending sort (e.g.,"-x"to sort by x-field, descending). This channel string is short-form of a sort-by-encoding definition. For example,"sort": "-x"is equivalent to"sort": {"encoding": "x", "order": "descending"}. - A sort field definition for sorting by another field.
- An array specifying the field values in preferred
order. In this case, the
sort order will obey the values in the array, followed by any unspecified values in their
original order. For discrete time field, values in the sort array can be date-time
definition objects. In addition, for time units
"month"and"day", the values can be the month or day names (case insensitive) or their 3-letter initials (e.g.,"Mon","Tue"). nullindicating no sort.
Default value: "ascending"
Note: null and sorting by another channel is not supported for row and column.
See also: sort documentation.
time_unit: Option<LogicalNotPredicateTimeUnit>Time unit (e.g., year, yearmonth, month, hours) for a temporal field. or a
temporal field that gets casted as
ordinal.
Default value: undefined (None)
See also: timeUnit
documentation.
title: RemovableValue<LegendText>A title for the field. If null, the title will be removed.
Default value: derived from the field’s name and transformation function
(aggregate, bin and timeUnit). If the field has an aggregate function, the function
is displayed as part of the title (e.g., "Sum of Profit"). If the field is binned or
has a time unit applied, the applied function is shown in parentheses (e.g., "Profit (binned)", "Transaction Date (year-month)"). Otherwise, the title is simply the field
name.
Notes:
-
You can customize the default field title format by providing the
fieldTitleproperty in the config orfieldTitlefunction via thecompilefunction’s options. -
If both field definition’s
titleand axis, header, or legendtitleare defined, axis/header/legend title will be used.
mark_prop_def_gradient_string_null_type: Option<Type>The type of measurement ("quantitative", "temporal", "ordinal", or "nominal") for
the encoded field or constant value (datum). It can also be a "geojson" type for
encoding ‘geoshape’.
Vega-Lite automatically infers data types in many cases as discussed below. However, type
is required for a field if: (1) the field is not nominal and the field encoding has no
specified aggregate (except argmin and argmax), bin, scale type, custom sort
order, nor timeUnit or (2) if you wish to use an ordinal scale for a field with bin
or timeUnit.
Default value:
- For a data
field,"nominal"is the default data type unless the field encoding hasaggregate,channel,bin, scale type,sort, ortimeUnitthat satisfies the following criteria:
"quantitative"is the default type if (1) the encoded field containsbinoraggregateexcept"argmin"and"argmax", (2) the encoding channel islatitudeorlongitudechannel or (3) if the specified scale type is a quantitative scale."temporal"is the default type if (1) the encoded field containstimeUnitor (2) the specified scale type is a time or utc scale"ordinal"is the default type if (1) the encoded field contains a customsortorder, (2) the specified scale type is an ordinal/point/band scale, or (3) the encoding channel isorder.
- For a constant value in data domain (
datum):
"quantitative"if the datum is a number"nominal"if the datum is a string"temporal"if the datum is a date time object
Note:
- Data
typedescribes the semantics of the data rather than the primitive data types (number, string, etc.). The same primitive data type can have different types of measurement. For example, numeric data can represent quantitative, ordinal, or nominal data. - Data values for a temporal field can be either a date-time string (e.g.,
"2015-03-07 12:32:17","17:01","2015-03-16"."2015") or a timestamp number (e.g.,1552199579097). - When using with
bin, thetypeproperty can be either"quantitative"(for using a linear bin scale) or"ordinal"(for using an ordinal bin scale). - When using with
timeUnit, thetypeproperty can be either"temporal"(default, for using a temporal scale) or"ordinal"(for using an ordinal scale). - When using with
aggregate, thetypeproperty refers to the post-aggregation data type. For example, we can calculate countdistinctof a categorical field"cat"using{"aggregate": "distinct", "field": "cat"}. The"type"of the aggregate output is"quantitative". - Secondary channels (e.g.,
x2,y2,xError,yError) do not havetypeas they must have exactly the same type as their primary channels (e.g.,x,y).
See also: type documentation.
datum: Option<PrimitiveValue>A constant value in data domain.
value: Option<ConditionalValueDefGradientStringNullExprRefValue>A constant value in visual domain (e.g., "red" / "#0099ff" / gradient
definition for color, values
between 0 to 1 for opacity).